@@ -1,6 +1,6 @@
 /*
  *  Canon Inkjet Printer Driver for Linux
- *  Copyright CANON INC. 2001-2019
+ *  Copyright CANON INC. 2001-2021
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -87,6 +87,10 @@ static char model_number[] = "com2";
 #define BJLIB_PATH "/usr/lib/bjlib/"
 #endif
 
+#ifdef __x86_64__
+		__asm__(".symver memcpy, memcpy@GLIBC_2.2.5");
+#endif
+
 int (*CNCL_MakeCommand_CancelJob)(char *, char *, unsigned int, unsigned int *);
 int (*CNCL_MakeCommand_GetStatus)(char *, unsigned int, unsigned int *);
 int (*GET_PROTOCOL)(char *, size_t);
