@@ -1,6 +1,6 @@
 /*
  *  Canon Inkjet Printer Driver for Linux
- *  Copyright CANON INC. 2001-2019
+ *  Copyright CANON INC. 2001-2021
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -36,6 +36,7 @@ static const MapTbl mediatypeTbl[] = {
 	{ "glossygold", CNCL_PSET_MEDIA_PHOTO_PAPER_PLUS_GLOSSY_II },
 	{ "photopaperpro2", CNCL_PSET_MEDIA_PHOTO_PAPER_PRO_II },
 	{ "proplatinum", CNCL_PSET_MEDIA_PHOTO_PAPER_PRO_PLATINUM },
+	{ "procrystalgrade", CNCL_PSET_MEDIA_PHOTO_PAPER_PRO_CRYSTAL_GRADE },
 	{ "photopaperpro", CNCL_PSET_MEDIA_PROPHOTO },
 	{ "superphoto", CNCL_PSET_MEDIA_SUPER_PHOTO_PAPER },
 	{ "luster", CNCL_PSET_MEDIA_PHOTO_PAPER_PRO_LUSTER },
@@ -68,6 +69,7 @@ static const MapTbl papersizeTbl[] = {
 	{ "a3plus", CNCL_PSET_SIZE_A3_PLUS },
 	{ "a3plus.bl", CNCL_PSET_SIZE_A3_PLUS },
 	{ "B5", CNCL_PSET_SIZE_B5 },
+	{ "B5.bl", CNCL_PSET_SIZE_B5 },
 	{ "B4", CNCL_PSET_SIZE_B4 },
 	{ "oficio", CNCL_PSET_SIZE_OFICIO },
 	{ "boficio", CNCL_PSET_SIZE_B_OFICIO },
