@@ -1,6 +1,6 @@
 /*
  *  CUPS add-on module for Canon Inkjet Printer.
- *  Copyright CANON INC. 2001-2019
+ *  Copyright CANON INC. 2001-2021
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -62,6 +62,10 @@
 #define CNIJRAW_TEMP "/var/tmp/cnijrawtmpXXXXXX"
 #define DUPLEX_LONGSIDE "duplexnotumble"
 
+#ifdef __x86_64__
+		__asm__(".symver memcpy, memcpy@GLIBC_2.2.5");
+#endif
+
 typedef ssize_t (*cups_raster_iocb_t)(void *ctx, unsigned char *buffer, size_t length );
 
 enum {
